from abc import ABC, abstractmethod
import re
from piidata.piidetector import PiiDetector

class AnonymizationAdapter(ABC):
    @abstractmethod
    def anonymize(self, text: str) -> str:
        pass

class Anonymizer(AnonymizationAdapter):
    def __init__(self, config):
        self.pre_scrub_patterns = config.get("anonymize_patterns", {})
        self.use_pii_data = config.get("use_pii_data", True)
        if self.use_pii_data:
            # Create PiiDetector instance
            self.pii_detector = PiiDetector()

    def pre_scrub(self, text: str) -> str:
        for pattern in self.pre_scrub_patterns.values():
            text = re.sub(pattern, "<anonymized>", text)
        return text

    def anonymize(self, text: str) -> str:
        text = self.pre_scrub(text)  # Always perform pre-scrubbing
        if self.use_pii_data:
            # Apply PiiData to anonymize
            detected_pii = self.pii_detector.detect_pii(text)
            for pii in detected_pii:
                text = text.replace(pii["entity"], "<anonymized>")
        return text



from setuptools import setup, find_packages

setup(
    name="log_abstractor",
    version="1.1.6",
    packages=find_packages(),
    install_requires=[
        "structlog>=24.4.0", "piidata>=1.0.0",#"scrubadub==2.0.0","regex",
        "re",
    ],
    description="Optimized anonymizer with pre-scrubbing.",
    author="Dipanjan Mazumder",
    author_email="javahub@yahoo.com",
    url="https://github.com/SMART2016/logger",  # Optional: Link to your project repository
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',  # Specify Python version compatibility
)



import os
import json

class LogConfig:
   # Automatically invoked when you create an object of LogConfig class
    def __init__(self, config_file_path=None):
        self.config_file_path = config_file_path or os.getenv("LOG_CONFIG_PATH", "log_config.json")
        self.config = self._load_config()

    def _load_config(self):
        # Load configuration from the provided JSON file path
        if os.path.exists(self.config_file_path):
            with open(self.config_file_path, "r") as file:
                config = json.load(file)
        else:
            config = {}

        # Override with environment variables if they exist
        config["log_level"] = os.getenv("LOG_LEVEL", config.get("log_level", "INFO"))
        config["log_destination"] = os.getenv("LOG_DESTINATION", config.get("log_destination", "console"))
        config["log_file_path"] = os.getenv("LOG_FILE_PATH", config.get("log_file_path", "app.log"))
        config["log_format"] = os.getenv("LOG_FORMAT", config.get("log_format", "json"))

        return config

    def get_config(self):
        return self.config
